%% plots GaAs 100 paper figure
load('set1_paper.mat');
DelaysToPlot = [-1 0 1 3 5];

fig = figure;
set(gcf,'position',[256   416   753   491])

idxToPlot = ismember(exp_delay,DelaysToPlot);
I1 = exp_lock(:,:,idxToPlot);
I2 = exp_fast(:,:,idxToPlot);
xaxis = exp_x;
yaxis = exp_y;
ROI = exp_ROI; 

for i = [1 2 3 4 5 6 7 8 9 10]
    s = subplot(2,5,i);
    if ismember(i,[1:5]) % top row
        imagesc(xaxis(1:(ROI(2)-ROI(1))),yaxis(1:(ROI(4)-ROI(3))),I1(ROI(1):ROI(2),ROI(3):ROI(4),i))
        text(20,40,(sprintf('%+.1f ns',DelaysToPlot(i))),'fontsize',11,'fontweight','bold');
    elseif ismember(i,[6:10]) % bot row
        imagesc(xaxis(1:(ROI(2)-ROI(1))),yaxis(1:(ROI(4)-ROI(3))),I2(ROI(1):ROI(2),ROI(3):ROI(4),i-5))
        text(20,40,(sprintf('%+.1f ns',DelaysToPlot(i-5))),'fontsize',11,'fontweight','bold');
    end
    axis equal tight off
    colormap(s,'hot')
    caxis([-1 1])
    
    % fix positions
    padding = 0.01;
    ypadding = 0.01;    
    poss = get(s,'position');
    if ismember(i,[1 6])
        set(s,'position',[.5*padding poss(2)  .18-padding poss(4)])
    elseif ismember(i,[2 7])
        set(s,'position',[.5*padding+.18 poss(2)  .18-padding poss(4)])
    elseif ismember(i,[3 8])
        set(s,'position',[.5*padding+.18*2 poss(2)  .18-padding poss(4)])
    elseif ismember(i,[4 9])
        set(s,'position',[.5*padding+.18*3  poss(2) .18-padding poss(4)])
    elseif ismember(i,[5 10])
        set(s,'position',[.5*padding+.18*4   poss(2) .18-padding poss(4)])
    end
    
    % draw scale bar
    rectangle('position',[50 .6*650+25 50 15],'facecolor',[0 0 0],'linewidth',1)
    
end
% Draw Colorbar
possub = get(gca,'position');
c = colorbar();
set(gca,'Position',possub)
set(c,'Position', [0.92 .15 .0186 .735]);
caxis([-1 1])
% title(c,'Laser induced SE signal intensity [V]','fontsize',11)
c.Label.String = 'Laser induced SE signal intensity [V]';
c.Label.FontSize = 11;


% plot fast dynamics
signalval = zeros(1,size(exp_fast,3));
for i = 1: size(exp_fast,3)
    A = exp_fast(ROI(1):ROI(2),ROI(3):ROI(4),i);
    A = sort(A(:));
    signalval(i) = mean(A(1:5));
end
[~,idxmin]= min(signalval);
tmin = exp_delay(idxmin);
fitfunc = '-a*exp(-b*x)+c';
[xdata,ydata] = prepareCurveData(exp_delay,signalval);
fit1 = fit(xdata,ydata,fitfunc,'Exclude',xdata<tmin,'start',[1 1/3 0]);
fig = figure; 
pos = get(fig,'position');
set (fig,'position',[pos(1) pos(2)-300 400 200])
plot(exp_delay,signalval,'o',tmin:.01:10,fit1(tmin:.01:10),'-r','linewidth',2)
legend('Data',sprintf('Fit with \\tau = %.1f ns',1/fit1.b),'location','southeast')
grid on
xlabel('Pump probe delay [ns]')
ylabel('LISE [V]')

% plot reference image
fig = figure; 
pos = get(fig,'position');
set (fig,'position',[pos(1) pos(2) 400 400])
imagesc(xaxis(1:(ROI(2)-ROI(1))),yaxis(1:(ROI(4)-ROI(3))),exp_Ref_Img(ROI(1):ROI(2),ROI(3):ROI(4)))
axis equal tight off
colormap('hot')
caxis([-1 1])
rectangle('position',[50 .6*650+25 50 15],'facecolor',[0 0 0],'linewidth',1)
% text(0,.6*550+50,'50 \mum','fontsize',11,'fontweight','bold')
set(gca,'position',[0.1 0.2 0.6 0.6])

possub = get(gca,'position');
c = colorbar();
set(gca,'Position',possub)
set(c,'Position', [0.75 .2 .05 .6]);
caxis([-1 1])
% title(c,'Laser induced SE signal intensity [V]','fontsize',11)
c.Label.String = 'Laser induced SE signal [V]';
c.Label.FontSize = 11;
    
