%% plots GaAs 111 figures
load('set1_AB_paper.mat');
DelaysToPlot = [-1.5 0 1 3 6];

fig = figure;
set(gcf,'position',[256   416   753   491])

idxToPlot = ismember(exp_delay_A,DelaysToPlot);
I1 = exp_lock_A(:,:,idxToPlot);
idxToPlot = ismember(exp_delay_B,DelaysToPlot);
I2 = exp_lock_B(:,:,idxToPlot);
xaxis = exp_x_A;
yaxis = exp_y_A;
ROI = [1 100 1 100];

for i = [1 2 3 4 5 6 7 8 9 10]
    s = subplot(2,5,i);
    if ismember(i,[1:5]) % top row
        imagesc(xaxis(1:(ROI(2)-ROI(1))),yaxis(1:(ROI(4)-ROI(3))),I1(ROI(1):ROI(2),ROI(3):ROI(4),i))
        text(20,40,(sprintf('%+.1f ns',DelaysToPlot(i))),'fontsize',11,'fontweight','bold');
    elseif ismember(i,[6:10]) % bot row
        imagesc(xaxis(1:(ROI(2)-ROI(1))),yaxis(1:(ROI(4)-ROI(3))),I2(ROI(1):ROI(2),ROI(3):ROI(4),i-5))
        text(20,40,(sprintf('%+.1f ns',DelaysToPlot(i-5))),'fontsize',11,'fontweight','bold');
    end
    axis equal tight off
    colormap(s,'hot')
    caxis([-1 1])
    
    % fix positions
    padding = 0.01;
    ypadding = 0.01;    
    poss = get(s,'position');
    if ismember(i,[1 6])
        set(s,'position',[.5*padding poss(2)  .18-padding poss(4)])
    elseif ismember(i,[2 7])
        set(s,'position',[.5*padding+.18 poss(2)  .18-padding poss(4)])
    elseif ismember(i,[3 8])
        set(s,'position',[.5*padding+.18*2 poss(2)  .18-padding poss(4)])
    elseif ismember(i,[4 9])
        set(s,'position',[.5*padding+.18*3  poss(2) .18-padding poss(4)])
    elseif ismember(i,[5 10])
        set(s,'position',[.5*padding+.18*4   poss(2) .18-padding poss(4)])
    end
    
    % draw scale bar
    rectangle('position',[50 300 50 15],'facecolor',[0 0 0],'linewidth',1)
    
end
% Draw Colorbar
possub = get(gca,'position');
c = colorbar();
set(gca,'Position',possub)
set(c,'Position', [0.92 .15 .0186 .735]);
caxis([-1 1])
% title(c,'Laser induced SE signal intensity [V]','fontsize',11)
c.Label.String = 'Laser induced SE signal intensity [V]';
c.Label.FontSize = 11;


% plot fast dynamics
signalvalA = zeros(1,size(exp_fast_A,3));
for i = 1: size(exp_fast_A,3)
    A = exp_fast_A(exp_ROI_A(1):exp_ROI_A(2),exp_ROI_A(3):exp_ROI_A(4),i);
    A = sort(A(:));
    signalvalA(i) = mean(A(1:5));
end
signalvalB = zeros(1,size(exp_fast_B,3));
for i = 1: size(exp_fast_B,3)
    A = exp_fast_B(exp_ROI_B(1):exp_ROI_B(2),exp_ROI_B(3):exp_ROI_B(4),i);
    A = sort(A(:));
    signalvalB(i) = mean(A(1:5));
end
[~,idxmin]= min(signalvalA);
tmin = exp_delay_A(idxmin);

fitfunc = '-a*exp(-b*x)+c';
[xdata,ydata] = prepareCurveData(exp_delay_A,signalvalA);
fit1 = fit(xdata,ydata,fitfunc,'Exclude',xdata<tmin,'start',[1 1/3 0]);
fitfunc = '-a*exp(-b*x)+c';
[xdata,ydata] = prepareCurveData(exp_delay_B,signalvalB);
fit2 = fit(xdata,ydata,fitfunc,'Exclude',xdata<tmin,'start',[1 1/3 0]);
fig = figure; 
pos = get(fig,'position');
set (fig,'position',[pos(1) pos(2)-300 400 200])
plot(exp_delay_A,signalvalA,'ob',tmin:.01:10,fit1(tmin:.01:10),'-b', ...
    exp_delay_B,signalvalB,'or',tmin:.01:10,fit2(tmin:.01:10),'-r','linewidth',2)
legend('Data GaAs (111)A',sprintf('Fit with \\tau = %.2g ns',1/fit1.b),...
    'Data GaAs (111)B',sprintf('Fit with \\tau = %.2g ns',1/fit2.b),...
    'location','southeast')
grid on
xlabel('Pump probe delay [ns]')
ylabel('LISE [V]')


% plot reference images    

fig = figure;
% GaAsA
s = subplot(1,2,1);
imagesc(xaxis,yaxis,exp_Ref_Img_A)
% text(20,40,(sprintf('%+.1f ns',8)),'fontsize',11,'fontweight','bold');
axis equal tight off
colormap(s,'hot')
caxis([-1 1])
% fix positions
padding = 2/3*0.03;
ypadding = 0.01;
poss = get(s,'position');
set(s,'position',[3/2*(0.5*padding) poss(2) 3/2*(1-3*padding)/3 poss(4)])
poss = get(s,'position');
set(s,'position',[poss(1) .2+0.5*ypadding poss(3) .85-ypadding])
% draw scale bar
rectangle('position',[50 300 50 15],'facecolor',[0 0 0],'linewidth',1)
title('GaAs (111)A','fontsize',12)

%GaAsB
s = subplot(1,2,2);
imagesc(xaxis,yaxis,exp_Ref_Img_B)
% text(20,40,(sprintf('%+.1f ns',8)),'fontsize',11,'fontweight','bold');
axis equal tight off
colormap(s,'hot')
caxis([-1 1])
% fix positions
padding = 2/3*0.03;
ypadding = 0.01;
poss = get(s,'position');
set(s,'position',[3/2*(1/3+0.5*padding) poss(2) 3/2*(1-3*padding)/3 poss(4)])
poss = get(s,'position');
set(s,'position',[poss(1) .2+0.5*ypadding poss(3) .85-ypadding])
% draw scale bar
rectangle('position',[50 300 50 15],'facecolor',[0 0 0],'linewidth',1)
title('GaAs (111)B','fontsize',12)

pos = get(fig,'position');
set (fig,'position',[pos(1) pos(2)-800 2/3*400 250])
c = colorbar('southoutside');
set(c,'Position', [padding/2 0.1  3/2*(2/3-padding)  2/3*1158/250*0.03])
caxis([-1 1])
title(c,'Laser induced SE signal intensity [V]','fontsize',11)