%% plots GaAs 111 figures

% Experimental data
load('set1_AB_paper.mat');
xaxis = exp_x_A;
yaxis = exp_y_A;
ProfileGaAsA = CalcLineProfileDiag(exp_lock_A(:,:,11),3); % get profiles at 8 ns
ProfileGaAsB = CalcLineProfileDiag(exp_lock_B(:,:,11),3);

ProfileGaAsApercent = ProfileGaAsA/130 /(-.3220--.96) *100; % 130 is lock-in gain, .3220 is SE signal, .96 is SE signal with beam off
ProfileGaAsBpercent = ProfileGaAsB/130 /(-.4115--.96) *100;

x = linspace(0,sqrt(2)*max(xaxis),100);

col = lines(3);
figure;
p = plot(x-230,ProfileGaAsApercent','.-',x-220, ProfileGaAsBpercent','.-');
set(p,{'color'},num2cell(col(1:2,:),2))
set(p,'markersize',5)
set(p,'LineWidth',2)
xlabel('X [\mum]')
ylabel('Signal intensity [V]')
ylabel('SE yield change [%]')
title('Experimental line profiles','fontsize',11)
xlim([-100 80])
ylim([-1 2])
hold on
xlims = get(gca,'xlim');
plot([xlims(1) xlims(2)], .2*[1 1],'--k')
legend('GaAs (111)A','GaAs (111)B','location','Northwest')
% grid on
pos = get(gcf,'position');
set(gcf,'position',[pos(1) pos(2) pos(3) .5*pos(4)])

% Simulation data
load('SimData')    
Ncoltotsummed = sum(Ncoltot(:,:,1:10),3)/10000;
Ncoltotsummed = conv2(Ncoltotsummed, [.25;.5;.25],'same');
%get number of SEs for zero voltage
NcoltotZero = [ Ncoltotsummed(:,1) Ncoltotsummed(:,1)  Ncoltotsummed(:,1)];

figure;
p = plot(xpos(1:19),(Ncoltotsummed(:,2:4)- (NcoltotZero))./ mean(NcoltotZero(:))*100,'linewidth',2 );
delete(p(3));
xlabel('X [\mum]')
ylabel('SE yield change [%]')
title('Simulated SE collection with local SPV','fontsize',11)
% grid on
hold on
xlims = get(gca,'xlim');
plot([xlims(1) xlims(2)], 0*[1 1],'--k')
legend('V = 100 mV','V = 200 mV','location','Northwest')
pos = get(gcf,'position');
set(gcf,'position',[pos(1) pos(2) pos(3) .5*pos(4)])




function profile=CalcLineProfileDiag(img,n)
% calculates a line profile along the diagonal of the image inputted.
% The off diagonals are also taken into consideration if n>0. The
% output is the profile.
profile1 = diag(img,0);
profilemat = nan([n+1,length(profile1)]);
profilemat(1,:) = profile1;
iter = 1;
for n = 1:n
    offDiagProfile = (diag(img,n)+diag(img,-n))./2;    
    if mod(n,2)==0 % if n is even
        profilemat(iter+1,1+n/2:end-n/2) = offDiagProfile;
    else
        lengthened = conv(offDiagProfile,[.5 .5]);
        profilemat(iter+1,2+(n-1)/2:end-1-(n-1)/2) = lengthened(2:end-1);
    end    
    iter = iter+1;     
end
profile = nansum(profilemat.* [1; 2*ones(n,1)])./(2*sum(~isnan(profilemat))-1);
end